==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/fi_FI.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Palvelimelta-palvelimelle-jakaminen ei ole käytössä tällä palvelimella",
    "The mountpoint name contains invalid characters." : "Liitospisteen nimi sisältää virheellisiä merkkejä.",
    "Not allowed to create a federated share with the same user server" : "Saman käyttäjäpalvelimen kanssa ei ole sallittua luoda federoitua jakoa",
    "Invalid or untrusted SSL certificate" : "Virheellinen tai ei-luotettu SSL-varmenne",
    "Could not authenticate to remote share, password might be wrong" : "Tunnistautuminen etäjakoa kohtaan epäonnistui. Salasana saattaa olla väärä",
    "Storage not valid" : "Tallennustila ei ole kelvollinen",
    "Couldn't add remote share" : "Etäjaon liittäminen epäonnistui",
    "Shared with you" : "Jaettu kanssasi",
    "Shared with others" : "Jaettu muiden kanssa",
    "Shared by link" : "Jaettu linkin kautta",
    "Federated sharing" : "Federoitu jakaminen",
    "Nothing shared with you yet" : "Kanssasi ei ole vielä jaettu mitään",
    "Files and folders others share with you will show up here" : "Kanssasi jaetut tiedostot ja kansiot näkyvät täällä",
    "Nothing shared yet" : "Ei mitään jaettua",
    "Files and folders you share will show up here" : "Jakamasi tiedostot ja kansiot näkyvät täällä",
    "No shared links" : "Ei jaettuja linkkejä",
    "Files and folders you share by link will show up here" : "Linkin kautta jakamasi tiedostot ja kansiot näkyvät täällä",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Haluatko lisätä etäjaon {name} kohteesta {owner}@{remote}?",
    "Remote share" : "Etäjako",
    "Remote share password" : "Etäjaon salasana",
    "Cancel" : "Peru",
    "Add remote share" : "Lisää etäjako",
    "You can upload into this folder" : "Voit lähettää tiedostoja tähän kansioon",
    "No ownCloud installation (7 or higher) found at {remote}" : "ownCloud-asennusta (versiota 7 tai uudempaa) ei löytynyt osoitteesta {remote}",
    "Invalid ownCloud url" : "Virheellinen ownCloud-osoite",
    "Shared by" : "Jakanut",
    "Sharing" : "Jakaminen",
    "A file or folder has been <strong>shared</strong>" : "Tiedosto tai kansio on <strong>jaettu</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Tiedosto tai kansio jaettiin <strong>toiselta palvelimelta</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Julkisesti jaettu tiedosto tai kansio <strong>ladattiin</strong>",
    "You received a new remote share %2$s from %1$s" : "Vastaanotit uuden etäjaon %2$s käyttäjältä %1$s",
    "You received a new remote share from %s" : "Vastaanotit uuden etäjaon käyttäjältä %s",
    "%1$s accepted remote share %2$s" : "%1$s hyväksyi etäjaon %2$s",
    "%1$s declined remote share %2$s" : "%1$s kieltäytyi etäjaosta %2$s",
    "%1$s unshared %2$s from you" : "%1$s lopetti kohteen %2$s jakamisen kanssasi",
    "Public shared folder %1$s was downloaded" : "Julkisesti jaettu kansio %1$s ladattiin",
    "Public shared file %1$s was downloaded" : "Julkisesti jaettu tiedosto %1$s ladattiin",
    "You shared %1$s with %2$s" : "Jaoit kohteen %1$s käyttäjän %2$s kanssa",
    "%2$s shared %1$s with %3$s" : "%2$s jakoi kohteen %1$s käyttäjän %3$s kanssa",
    "You shared %1$s with group %2$s" : "Jaoit kohteen %1$s ryhmän %2$s kanssa",
    "%2$s shared %1$s with group %3$s" : "%2$s jakoi kohteen %1$s ryhmän %3$s kanssa",
    "%2$s shared %1$s via link" : "%2$s jakoi kohteen %1$s linkin kautta",
    "You shared %1$s via link" : "Jaoit kohteen %1$s linkin kautta",
    "Your public link for %1$s expired" : "Julkinen linkkisi kohteelle %1$s vanhentui",
    "%2$s shared %1$s with you" : "%2$s jakoi kohteen %1$s kanssasi",
    "Downloaded via public link" : "Lataa julkista linkkiä käyttäen",
    "Shared with %2$s" : "Jaettu käyttäjän %2$s kanssa",
    "Shared with %3$s by %2$s" : "Jaettu käyttäjän %3$s kanssa käyttäjän %2$s toimesta",
    "Shared with group %2$s" : "Jaettu ryhmän %2$s kanssa",
    "Shared with group %3$s by %2$s" : "Jaettu ryhmän %3$s kanssa käyttäjän %2$s toimesta",
    "Shared via link by %2$s" : "Jaettu linkin kautta käyttäjän %2$s toimesta",
    "Shared via public link" : "Jaettu julkisen linkin kautta",
    "Removed public link" : "Julkinen linkki poistettu",
    "%2$s removed public link" : "%2$s poisti julkisen linkin",
    "Public link expired" : "Julkinen linkki vanhentui",
    "Public link of %2$s expired" : "Kohteen %2$s julkinen linkki vanhentui",
    "Shared by %2$s" : "Jakanut %2$s",
    "Shares" : "Jaot",
    "You received \"/%2$s\" as a remote share from %1$s" : "Vastaanotit kohteen \"/%2$s\" etäjakona käyttäjältä %1$s",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Jaa kanssani käyttäen #ownCloud ja federoitua pilvitunnistetta, katso %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Jaa kanssani käyttäen #ownCloud ja federoitua pilvitunnistetta",
    "This share is password-protected" : "Tämä jako on suojattu salasanalla",
    "The password is wrong. Try again." : "Väärä salasana. Yritä uudelleen.",
    "Password" : "Salasana",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Name" : "Nimi",
    "Share time" : "Jakamisen ajankohta",
    "Sorry, this link doesn’t seem to work anymore." : "Valitettavasti linkki ei vaikuta enää toimivan.",
    "Reasons might be:" : "Mahdollisia syitä:",
    "the item was removed" : "kohde poistettiin",
    "the link expired" : "linkki vanheni",
    "sharing is disabled" : "jakaminen on poistettu käytöstä",
    "For more info, please ask the person who sent this link." : "Kysy lisätietoja henkilöltä, jolta sait linkin.",
    "Add to your ownCloud" : "Lisää ownCloudiisi",
    "Download" : "Lataa",
    "Download %s" : "Lataa %s",
    "Direct link" : "Suora linkki",
    "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
    "Open documentation" : "Avaa dokumentaatio",
    "Allow users on this server to send shares to other servers" : "Salli tämän palvelimen käyttäjien lähettää jakoja muille palvelimille",
    "Allow users on this server to receive shares from other servers" : "Salli tämän palvelimen käyttäjien vastaanottaa jakoja muilta palvelimilta",
    "Federated Cloud" : "Federoitu pilvi",
    "Your Federated Cloud ID:" : "Federoidun pilvesi tunniste:",
    "Share it:" : "Jaa se:",
    "Add to your website" : "Lisää verkkosivuillesi",
    "Share with me via ownCloud" : "Jaa kanssani ownCloudin kautta",
    "HTML Code:" : "HTML-koodi:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/fi_FI.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Palvelimelta-palvelimelle-jakaminen ei ole käytössä tällä palvelimella",
    "The mountpoint name contains invalid characters." : "Liitospisteen nimi sisältää virheellisiä merkkejä.",
    "Not allowed to create a federated share with the same user server" : "Saman käyttäjäpalvelimen kanssa ei ole sallittua luoda federoitua jakoa",
    "Invalid or untrusted SSL certificate" : "Virheellinen tai ei-luotettu SSL-varmenne",
    "Could not authenticate to remote share, password might be wrong" : "Tunnistautuminen etäjakoa kohtaan epäonnistui. Salasana saattaa olla väärä",
    "Storage not valid" : "Tallennustila ei ole kelvollinen",
    "Couldn't add remote share" : "Etäjaon liittäminen epäonnistui",
    "Shared with you" : "Jaettu kanssasi",
    "Shared with others" : "Jaettu muiden kanssa",
    "Shared by link" : "Jaettu linkin kautta",
    "Federated sharing" : "Federoitu jakaminen",
    "Nothing shared with you yet" : "Kanssasi ei ole vielä jaettu mitään",
    "Files and folders others share with you will show up here" : "Kanssasi jaetut tiedostot ja kansiot näkyvät täällä",
    "Nothing shared yet" : "Ei mitään jaettua",
    "Files and folders you share will show up here" : "Jakamasi tiedostot ja kansiot näkyvät täällä",
    "No shared links" : "Ei jaettuja linkkejä",
    "Files and folders you share by link will show up here" : "Linkin kautta jakamasi tiedostot ja kansiot näkyvät täällä",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Haluatko lisätä etäjaon {name} kohteesta {owner}@{remote}?",
    "Remote share" : "Etäjako",
    "Remote share password" : "Etäjaon salasana",
    "Cancel" : "Peru",
    "Add remote share" : "Lisää etäjako",
    "You can upload into this folder" : "Voit lähettää tiedostoja tähän kansioon",
    "No ownCloud installation (7 or higher) found at {remote}" : "ownCloud-asennusta (versiota 7 tai uudempaa) ei löytynyt osoitteesta {remote}",
    "Invalid ownCloud url" : "Virheellinen ownCloud-osoite",
    "Shared by" : "Jakanut",
    "Sharing" : "Jakaminen",
    "A file or folder has been <strong>shared</strong>" : "Tiedosto tai kansio on <strong>jaettu</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Tiedosto tai kansio jaettiin <strong>toiselta palvelimelta</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Julkisesti jaettu tiedosto tai kansio <strong>ladattiin</strong>",
    "You received a new remote share %2$s from %1$s" : "Vastaanotit uuden etäjaon %2$s käyttäjältä %1$s",
    "You received a new remote share from %s" : "Vastaanotit uuden etäjaon käyttäjältä %s",
    "%1$s accepted remote share %2$s" : "%1$s hyväksyi etäjaon %2$s",
    "%1$s declined remote share %2$s" : "%1$s kieltäytyi etäjaosta %2$s",
    "%1$s unshared %2$s from you" : "%1$s lopetti kohteen %2$s jakamisen kanssasi",
    "Public shared folder %1$s was downloaded" : "Julkisesti jaettu kansio %1$s ladattiin",
    "Public shared file %1$s was downloaded" : "Julkisesti jaettu tiedosto %1$s ladattiin",
    "You shared %1$s with %2$s" : "Jaoit kohteen %1$s käyttäjän %2$s kanssa",
    "%2$s shared %1$s with %3$s" : "%2$s jakoi kohteen %1$s käyttäjän %3$s kanssa",
    "You shared %1$s with group %2$s" : "Jaoit kohteen %1$s ryhmän %2$s kanssa",
    "%2$s shared %1$s with group %3$s" : "%2$s jakoi kohteen %1$s ryhmän %3$s kanssa",
    "%2$s shared %1$s via link" : "%2$s jakoi kohteen %1$s linkin kautta",
    "You shared %1$s via link" : "Jaoit kohteen %1$s linkin kautta",
    "Your public link for %1$s expired" : "Julkinen linkkisi kohteelle %1$s vanhentui",
    "%2$s shared %1$s with you" : "%2$s jakoi kohteen %1$s kanssasi",
    "Downloaded via public link" : "Lataa julkista linkkiä käyttäen",
    "Shared with %2$s" : "Jaettu käyttäjän %2$s kanssa",
    "Shared with %3$s by %2$s" : "Jaettu käyttäjän %3$s kanssa käyttäjän %2$s toimesta",
    "Shared with group %2$s" : "Jaettu ryhmän %2$s kanssa",
    "Shared with group %3$s by %2$s" : "Jaettu ryhmän %3$s kanssa käyttäjän %2$s toimesta",
    "Shared via link by %2$s" : "Jaettu linkin kautta käyttäjän %2$s toimesta",
    "Shared via public link" : "Jaettu julkisen linkin kautta",
    "Removed public link" : "Julkinen linkki poistettu",
    "%2$s removed public link" : "%2$s poisti julkisen linkin",
    "Public link expired" : "Julkinen linkki vanhentui",
    "Public link of %2$s expired" : "Kohteen %2$s julkinen linkki vanhentui",
    "Shared by %2$s" : "Jakanut %2$s",
    "Shares" : "Jaot",
    "You received \"/%2$s\" as a remote share from %1$s" : "Vastaanotit kohteen \"/%2$s\" etäjakona käyttäjältä %1$s",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Jaa kanssani käyttäen #ownCloud ja federoitua pilvitunnistetta, katso %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Jaa kanssani käyttäen #ownCloud ja federoitua pilvitunnistetta",
    "This share is password-protected" : "Tämä jako on suojattu salasanalla",
    "The password is wrong. Try again." : "Väärä salasana. Yritä uudelleen.",
    "Password" : "Salasana",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Name" : "Nimi",
    "Share time" : "Jakamisen ajankohta",
    "Sorry, this link doesn’t seem to work anymore." : "Valitettavasti linkki ei vaikuta enää toimivan.",
    "Reasons might be:" : "Mahdollisia syitä:",
    "the item was removed" : "kohde poistettiin",
    "the link expired" : "linkki vanheni",
    "sharing is disabled" : "jakaminen on poistettu käytöstä",
    "For more info, please ask the person who sent this link." : "Kysy lisätietoja henkilöltä, jolta sait linkin.",
    "Add to your ownCloud" : "Lisää ownCloudiisi",
    "Download" : "Lataa",
    "Download %s" : "Lataa %s",
    "Direct link" : "Suora linkki",
    "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
    "Open documentation" : "Avaa dokumentaatio",
    "Allow users on this server to send shares to other servers" : "Salli tämän palvelimen käyttäjien lähettää jakoja muille palvelimille",
    "Allow users on this server to receive shares from other servers" : "Salli tämän palvelimen käyttäjien vastaanottaa jakoja muilta palvelimilta",
    "Federated Cloud" : "Federoitu pilvi",
    "Your Federated Cloud ID:" : "Federoidun pilvesi tunniste:",
    "Share it:" : "Jaa se:",
    "Add to your website" : "Lisää verkkosivuillesi",
    "Share with me via ownCloud" : "Jaa kanssani ownCloudin kautta",
    "HTML Code:" : "HTML-koodi:",
    "Public link of %2$s expired" : "Kohteen %2$s julkinen linkki vanhentui",
    "Public shared file %1$s was downloaded" : "Julkisesti jaettu tiedosto %1$s ladattiin",
    "Public shared folder %1$s was downloaded" : "Julkisesti jaettu kansio %1$s ladattiin",
    "Shared by %2$s" : "Jakanut %2$s",
    "Shared via link by %2$s" : "Jaettu linkin kautta käyttäjän %2$s toimesta",
    "Shared with group %3$s by %2$s" : "Jaettu ryhmän %3$s kanssa käyttäjän %2$s toimesta",
    "Your public link for %1$s expired" : "Julkinen linkkisi kohteelle %1$s vanhentui"
},
"nplurals=2; plural=(n != 1);");
